@@ -2,7 +2,7 @@
 
 The MIT License
 
-Copyright (c) 2008-2011 Eduardo Naufel Schettino
+Copyright (c) 2008-2012 Eduardo Naufel Schettino
 
 Permission is hereby granted, free of charge, to any person obtaining a copy
 of this software and associated documentation files (the "Software"), to deal
@@ -23,17 +23,7 @@ OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 THE SOFTWARE.
 """
 
-__version__ = (0, 15, 0)
-
-# Use simplejson or Python 2.6 json
-# simplejson is much faster that py26:json. so use simplejson if available
-try:
-    import simplejson
-    json = simplejson
-except ImportError: # pragma: no cover
-    import json
-json # pyflakes
-
+__version__ = (0, 16, 0)
 
 
 # used to save variable values passed from command line
