@@ -23,6 +23,23 @@ def isgenerator(obj):
     return type(obj) is types.GeneratorType
 
 
+def flat_generator(gen, gen_doc=''):
+    """return only values from generators
+    if any generator yields another generator it is recursivelly called
+    """
+    for item in gen:
+        if isgenerator(item):
+            if hasattr(item, 'gi_code'):
+                item_doc = item.gi_code.co_consts[0]
+            else: # pragma: nocover
+                # python2.5 does not have gi_code on generators
+                item_doc = gen_doc
+            for value, value_doc in flat_generator(item, item_doc):
+                yield value, value_doc
+        else:
+            yield item, gen_doc
+
+
 def get_module(dodo_file, cwd=None, seek_parent=False):
     """
     @param dodo_file(str): path to file containing the tasks
@@ -31,6 +48,7 @@ def get_module(dodo_file, cwd=None, seek_parent=False):
     @return (module) dodo module
     """
     def exist_or_raise(path):
+        """raise exception if file on given path doesnt exist"""
         if not os.path.exists(path):
             msg = ("Could not find dodo file '%s'.\n" +
                    "Please use '-f' to specify file name.\n")
@@ -77,11 +95,10 @@ def get_module(dodo_file, cwd=None, seek_parent=False):
     os.chdir(full_cwd)
 
     # get module containing the tasks
-    # FIXME catche errors here
     return __import__(os.path.splitext(file_name)[0])
 
 
-def load_task_generators(dodo_module, command_names=()):
+def load_dodo_file(dodo_module, command_names=()):
     """Loads a python file and extracts its task generator functions.
 
     The python file is a called "dodo" file.
@@ -90,7 +107,7 @@ def load_task_generators(dodo_module, command_names=()):
     @param command_names: (list - str) blacklist for task names
     @return (dict):
      - task_list (list) of Tasks in the order they were defined on the file
-     - default_tasks (list) of tasks to be executed by default
+     - config (dict) doit config from dodo file
     """
 
     # get functions defined in the module and select the task generators
@@ -122,6 +139,7 @@ def load_task_generators(dodo_module, command_names=()):
     for name, ref, line in funcs:
         task_list.extend(generate_tasks(name, ref(), ref.__doc__))
 
+    # get config
     doit_config = getattr(dodo_module, 'DOIT_CONFIG', {})
     if not isinstance(doit_config, dict):
         msg = ("DOIT_CONFIG  must be a dict. got:'%s'%s")
@@ -130,58 +148,103 @@ def load_task_generators(dodo_module, command_names=()):
     return {'task_list': task_list,
             'config': doit_config}
 
-def generate_tasks(name, gen_result, gen_doc=None):
+
+def _generate_task_from_return(func_name, task_dict, gen_doc):
+    """generate a single task from a dict return'ed by a task generator"""
+    if 'name' in task_dict:
+        raise InvalidTask("Task '%s'. Only subtasks use field name." %
+                          func_name)
+
+    task_dict['name'] = task_dict.pop('basename', func_name)
+
+    # Use task generator docstring
+    # if no doc present in task dict
+    if not 'doc' in task_dict:
+        task_dict['doc'] = gen_doc
+
+    return dict_to_task(task_dict)
+
+
+def _generate_task_from_yield(tasks, func_name, task_dict, gen_doc):
+    """generate a single task from a dict yield'ed by task generator
+
+    @param tasks: dictionary with created tasks
+    @return None: the created task is added to 'tasks' dict
+    """
+    # check valid input
+    if not isinstance(task_dict, dict):
+        raise InvalidTask("Task '%s' must yield dictionaries" %
+                          func_name)
+
+    msg_dup = "Task generation '%s' has duplicated definition of '%s'"
+    basename = task_dict.pop('basename', None)
+    # if has 'name' this is a sub-task
+    if 'name' in task_dict:
+        basename = basename or func_name
+        # name is '<task>.<subtask>'
+        task_dict['name'] = "%s:%s"% (basename, task_dict['name'])
+        sub_task = dict_to_task(task_dict)
+        sub_task.is_subtask = True
+
+        group_task = tasks.get(basename)
+        if group_task:
+            if not group_task.has_subtask:
+                raise InvalidTask(msg_dup % (func_name, basename))
+        else:
+            group_task = Task(basename, None, doc=gen_doc, has_subtask=True)
+            tasks[basename] = group_task
+        group_task.task_dep.append(sub_task.name)
+        tasks[sub_task.name] = sub_task
+    # NOT a sub-task
+    else:
+        if not basename:
+            raise InvalidTask(
+                "Task '%s' must contain field 'name' or 'basename'. %s"%
+                (func_name, task_dict))
+        if basename in tasks:
+            raise InvalidTask(msg_dup % (func_name, basename))
+        task_dict['name'] = basename
+        # Use task generator docstring if no doc present in task dict
+        if not 'doc' in task_dict:
+            task_dict['doc'] = gen_doc
+        tasks[basename] = dict_to_task(task_dict)
+
+
+def generate_tasks(func_name, gen_result, gen_doc=None):
     """Create tasks from a task generator result.
 
-    @param name: (string) name of taskgen function
+    @param func_name: (string) name of taskgen function
     @param gen_result: value returned by a task generator function
+                       it can be a dict or generator (generating dicts)
     @param gen_doc: (string/None) docstring from the task generator function
-    @return: (tuple) task,list of subtasks
+    @return: (tuple) task, list of subtasks
     """
     # task described as a dictionary
     if isinstance(gen_result, dict):
-        if 'name' in gen_result:
-            raise InvalidTask("Task %s. Only subtasks use field name."%name)
-
-        gen_result['name'] = name
-
-        # Use task generator docstring
-        # if no doc present in task dict
-        if not 'doc' in gen_result:
-            gen_result['doc'] = gen_doc
-
-        return [dict_to_task(gen_result)]
+        return [_generate_task_from_return(func_name, gen_result, gen_doc)]
 
     # a generator
     if isgenerator(gen_result):
-        group_task = Task(name, None, doc=gen_doc)
-        tasks = [group_task]
-        # the generator return subtasks as dictionaries .
-        for task_dict in gen_result:
-            # check valid input
-            if not isinstance(task_dict, dict):
-                raise InvalidTask("Task %s must yield dictionaries"% name)
+        tasks = {} # task_name: task
+        # the generator return subtasks as dictionaries
+        for task_dict, x_doc in flat_generator(gen_result, gen_doc):
+            _generate_task_from_yield(tasks, func_name, task_dict, x_doc)
 
-            if 'name' not in task_dict:
-                raise InvalidTask("Task %s must contain field name. %s"%
-                                  (name,task_dict))
-            # name is task.subtask
-            task_dict['name'] = "%s:%s"% (name, task_dict.get('name'))
-            sub_task = dict_to_task(task_dict)
-            sub_task.is_subtask = True
-            tasks.append(sub_task)
+        if tasks:
+            return tasks.values()
+        else:
+            # special case task_generator did not generate any task
+            # create an empty group task
+            return [Task(func_name, None, doc=gen_doc, has_subtask=True)]
 
-        # add task dependencies to group task.
-        group_task.task_dep = [task.name for task in tasks[1:]]
-        return tasks
-
-    raise InvalidTask("Task %s. Must return a dictionary. got %s" %
-                      (name, type(gen_result)))
+    raise InvalidTask(
+        "Task '%s'. Must return a dictionary or generator. Got %s" %
+        (func_name, type(gen_result)))
 
 
 def get_tasks(dodo_file, cwd, seek_parent, command_names):
     """get tasks from dodo_file"""
     dodo_module = get_module(dodo_file, cwd, seek_parent)
-    return load_task_generators(dodo_module, command_names)
+    return load_dodo_file(dodo_module, command_names)
 
 
