@@ -28,7 +28,8 @@ class Task(object):
     @ivar uptodate: (list - bool/None) use bool/computed value instead of
                                        checking dependencies
     @ivar setup_tasks (list - string): references to task-names
-    @ivar is_subtask: (bool) indicate this task is a subtask.
+    @ivar is_subtask: (bool) indicate this task is a subtask
+    @ivar has_subtask: (bool) indicate this task has subtasks
     @ivar result: (str) last action "result". used to check task-result-dep
     @ivar values: (dict) values saved by task that might be used by other tasks
     @ivar getargs: (dict) values from other tasks
@@ -51,7 +52,8 @@ class Task(object):
     DEFAULT_VERBOSITY = 1
 
     # list of valid types/values for each task attribute.
-    valid_attr = {'name': ((str,), ()),
+    valid_attr = {'basename': ((str,), ()),
+                  'name': ((str,), ()),
                   'actions': ((list, tuple,), (None,)),
                   'file_dep': ((list, tuple,), ()),
                   'task_dep': ((list, tuple,), ()),
@@ -72,7 +74,8 @@ class Task(object):
 
     def __init__(self, name, actions, file_dep=(), targets=(),
                  task_dep=(), result_dep=(), uptodate=(),
-                 calc_dep=(), setup=(), clean=(), teardown=(), is_subtask=False,
+                 calc_dep=(), setup=(), clean=(), teardown=(),
+                 is_subtask=False, has_subtask=False,
                  doc=None, params=(), verbosity=None, title=None, getargs=None):
         """sanity checks and initialization
 
@@ -107,6 +110,7 @@ class Task(object):
         self._init_deps(file_dep, task_dep, result_dep, calc_dep)
         self.targets = targets
         self.is_subtask = is_subtask
+        self.has_subtask = has_subtask
         self.result = None
         self.values = {}
         self.verbosity = verbosity
@@ -248,14 +252,27 @@ class Task(object):
     def _init_getargs(self):
         """task getargs attribute define implicit task dependencies"""
         self._init_options()
-        for key, desc in self.getargs.iteritems():
-            # check format
-            parts = desc.rsplit('.', 1)
-            if len(parts) != 2:
-                msg = ("Taskid '%s' - Invalid format for getargs of '%s'.\n" %
-                       (self.name, key) +
-                       "Should be <taskid>.<argument-name> got '%s'\n" % desc)
-                raise InvalidTask(msg)
+        for arg_name, desc in self.getargs.iteritems():
+            # value can a string task_id.key_name (deprecated)...
+            if isinstance(desc, basestring):
+                # TODO raise deprecation warning
+                parts = desc.rsplit('.', 1)
+                if len(parts) != 2:
+                    msg = ("Taskid '%s' - Invalid format for getargs of '%s'.\n" %
+                           (self.name, arg_name) +
+                           "Should be <taskid>.<key-name> got '%s'\n" % desc)
+                    raise InvalidTask(msg)
+                self.getargs[arg_name] = parts
+            # ... or tuple (task_id, key_name)
+            else:
+                parts = desc
+                if len(parts) != 2:
+                    msg = ("Taskid '%s' - Invalid format for getargs of '%s'.\n" %
+                           (self.name, arg_name) +
+                           "Should be tuple with 2 elements " +
+                           "('<taskid>', '<key-name>') got '%s'\n" % desc)
+                    raise InvalidTask(msg)
+
             if parts[0] not in self.setup_tasks:
                 self.setup_tasks.append(parts[0])
 
@@ -431,6 +448,7 @@ class Task(object):
         inst.targets = self.targets[:]
         inst.uptodate = self.uptodate[:]
         inst.is_subtask = self.is_subtask
+        inst.has_subtask = self.has_subtask
         inst.result = self.result
         inst.values = self.values.copy()
         inst.verbosity = self.verbosity
